@@ -148,30 +148,26 @@ def add_command_box_tab():
 
 
 # Data loading and related helpers --------------------------------------------------------------------------------
-def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0, no_empty=None):
+def parse_load_cx_ods_kw(gfile=None, device=None, shot=None, t=None, efitid=None, index=0, no_empty=None, settings=None):
     """
-    Puts an ODS with CX info in the tree
+    Handles setting defaults for keywords to load_cx_ods()
 
-    :param gfile: OMFITgeqdsk instance [optional if shot, t, and efitid are supplied]
+    Keeps load_cx_ods() simpler and allows isolated testing. load_cx_ods() is
+    called by GUI buttons, and OMFIT GUIs are difficult to test. So, this helps
+    accomplish some limited GUI testing.
 
-    :param device: string
+    :param kw: keywords passed to load_cx_ods
 
-    :param shot: int [ignored if gfile is supplied]
-
-    :param t: int [ignored if gfile is supplied]
-        Leave it as None to load minimal data for all slices,
-        or specify a single time to load just one complete slice
-
-    :param efitid: string [ignored if gfile is supplied]
-
-    :param index: int
-        Index of the ODS, for managing multi-shot overlays
-
-    :return: ODS instance
+    :return: tuple containing
+        gfile: OMFITgeqdsk or None
+        device: str
+        shot: int
+        efitid: str
+        no_empty: bool
+        ods_tag: str
     """
-    printd(f'  loading cx ods for index {index}', topic='omfit_efitviewer')
-    out_loc, settings_loc, out, settings, parent_settings, scratch = pick_output_location()
-
+    if settings is None:
+        _, _, _, settings, _, _ = pick_output_location()
     the_case = settings['cases'][index]
     def_def_gfile = settings['cases'][0]['gfile']
     def_def_device = tokamak(settings['cases'][0]['device'])
@@ -189,6 +185,8 @@ def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0
 
     if gfile is None:
         gfile = def_gfile
+    if gfile == 'unused':
+        gfile = None
     if device is None:
         device = def_device
     if shot is None:
@@ -198,6 +196,37 @@ def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0
     if no_empty is None:
         no_empty = settings.setdefault('no_empty', True)
 
+    return gfile, device, shot, efitid, no_empty, ods_tag
+
+
+def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0, no_empty=None):
+    """
+    Puts an ODS with CX info in the tree
+
+    :param gfile: OMFITgeqdsk instance [optional if shot, t, and efitid are supplied]
+        Pass in 'unused' to prevent None from being used as an instruction to seek out a default value.
+
+    :param device: string
+
+    :param shot: int [ignored if gfile is supplied]
+
+    :param t: int [ignored if gfile is supplied]
+        Leave it as None to load minimal data for all slices,
+        or specify a single time to load just one complete slice
+
+    :param efitid: string [ignored if gfile is supplied]
+
+    :param index: int
+        Index of the ODS, for managing multi-shot overlays
+
+    :return: ODS instance
+    """
+    printd(f'  loading cx ods for index {index}', topic='omfit_efitviewer')
+    _, _, out, settings, _, _ = pick_output_location()
+    gfile, device, shot, efitid, no_empty, ods_tag = parse_load_cx_ods_kw(
+        gfile=gfile, device=device, shot=shot, t=t, efitid=efitid, index=index, no_empty=no_empty, settings=settings
+    )
+
     if isinstance(gfile, str):
         gfile_str = gfile
         gfile = eval(gfile)
@@ -211,9 +240,12 @@ def load_cx_ods(gfile=None, device=None, shot=None, t=None, efitid=None, index=0
             repr(device), repr(shot), repr(t), repr(efitid), no_empty
         )
         ods = out[ods_tag] = setup_hardware_overlay_cx(device, shot, t, efitid=efitid, default_load=False, quiet=True, no_empty=no_empty)
+        ods['dataset_description.ids_properties.source'] = 'MDSplus'
     else:
+        printd(f' Using a gfile or set with type {type(gfile)} to setup cx data.', topic='omfit_efitviewer')
         ods = out[ods_tag] = setup_hardware_overlay_cx(device, geqdsk=gfile, default_load=False, quiet=True, no_empty=no_empty)
         load_cmd = "setup_hardware_overlay_cx({}, geqdsk={}, default_load=False, no_empty={})".format(repr(device), gfile_str, no_empty)
+        ods['dataset_description.ids_properties.source'] = gfile_str
 
     settings['cases'][index]['instructions_for_loading_ods'] = load_cmd
     if 'equilibrium' not in ods or 'time' not in ods['equilibrium']:
@@ -619,7 +651,7 @@ def setup_special_contours(case=0, t=None, contour_quantity=None, spacing=None,
     if contour_quantity in ['psi', 'PSI']:
         cq = eq_slice['profiles_2d'][0]['psi']
         cq1d = eq_psi
-    elif contour_quantity in ['psin', 'PSIN', 'psi_n', 'PSI_N']:
+    elif contour_quantity.lower() in ['psin', 'psi_n', 'psi_norm']:
         psi_bdry = eq_slice['global_quantities']['psi_boundary']
         psi_axis = eq_slice['global_quantities']['psi_axis']
         cq = (eq_slice['profiles_2d'][0]['psi'] - psi_axis) / (psi_bdry - psi_axis)
@@ -651,13 +683,13 @@ def setup_special_contours(case=0, t=None, contour_quantity=None, spacing=None,
             except ValueError:
                 ref_r = ref_z = np.NaN
             if np.isnan(ref_r) or np.isnan(ref_z):
-                raise ValueError('Outer lower strike point not defined; might be a limited shape or just missing from ODS')
+                raise ValueError('Outer lower strike point not defined; might be a limited or upper-biased shape or just missing from ODS')
         elif space_ref.lower() in ['outer_upper_strike']:
             # omfit_omas.multi_efit_to_omas() loads strike points in a set order: low out, low in, up out, up in
             ref_r = eq_slice['boundary.strike_point.2.r']
             ref_z = eq_slice['boundary.strike_point.2.z']
             if np.isnan(ref_r) or np.isnan(ref_z):
-                raise ValueError('Outer upper strike point not defined; might be a limited shape or just missing from ODS')
+                raise ValueError('Outer upper strike point not defined; might be a limited or lower-biased shape or just missing from ODS')
         else:
             raise ValueError('Unrecognized custom contour spacing reference: {}'.format(space_ref))
         if space_q in ['R', 'Rmaj', 'R_major']:
