@@ -1094,23 +1094,34 @@ class OMFITmars(SortedDict, OMFITobject):
         ax.set_ylabel('Z [m]')
         fig.tight_layout()
 
-    def plot_JPLASMA(self, fig=None):
+    def plot_JPLASMA(self, Mmax=5, fig=None):
         """
         Plot perturbed current components J1,J2,J3
         :param fig: specify target figure
         """
         from matplotlib import pyplot
+        from labellines import labelLine, labelLines
 
         if fig is None:
             fig = pyplot.figure()
         ax = None
         label = 'JPLASMA'
+        MM = self[label]['Mm'].values
+        labelstring = [str(m) for m in MM]
         for k, c in enumerate(['JM1', 'JM2', 'JM3']):
             ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
+            for i, line in enumerate(ax1.lines):
+                line.set_label(labelstring[i])
+            lines1 = ax1.get_lines()
+            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax1.set_title('Re($J^%d_m$)' % (k + 1), y=0.8)
             ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
+            for i, line in enumerate(ax2.lines):
+                line.set_label(labelstring[i])
+            lines2 = ax2.get_lines()
+            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax2.set_title('Im($J^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('s')
         ax2.set_xlabel('s')
@@ -1137,45 +1148,69 @@ class OMFITmars(SortedDict, OMFITobject):
         ax.legend(loc=0)
         fig.tight_layout()
 
-    def plot_BPLASMA(self, fig=None):
+    def plot_BPLASMA(self, Mmax=5, fig=None):
         """
         Plot perturbed field components B1,B2,B3
+        :param Mmax: upper poloidal harmonic for labeling
         :param fig: specify target figure
         """
         from matplotlib import pyplot
+        from labellines import labelLine, labelLines
 
         if fig is None:
             fig = pyplot.figure()
         ax = None
         label = 'BPLASMA'
+        MM = self[label]['Mm'].values
+        labelstring = [str(m) for m in MM]
         for k, c in enumerate(['BM1', 'BM2', 'BM3']):
             ax = ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['s'], np.real(self[label][c]))
+            for i, line in enumerate(ax1.lines):
+                line.set_label(labelstring[i])
+            lines1 = ax1.get_lines()
+            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax1.set_title('Re($B^%d_m$)' % (k + 1), y=0.8)
             ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['s'], np.imag(self[label][c]))
+            for i, line in enumerate(ax2.lines):
+                line.set_label(labelstring[i])
+            lines2 = ax2.get_lines()
+            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax2.set_title('Im($B^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('s')
         ax2.set_xlabel('s')
         fig.tight_layout()
 
-    def plot_XPLASMA(self, fig=None):
+    def plot_XPLASMA(self, Mmax=5, fig=None):
         """
         Plot plasma displacement components X1,X2,X3
+        :param Mmax: upper poloidal harmonic for labeling
         :param fig: specify target figure
         """
         from matplotlib import pyplot
+        from labellines import labelLine, labelLines
 
         if fig is None:
             fig = pyplot.figure()
         ax = None
         label = 'XPLASMA'
+        MM = self[label]['Mm'].values
+        labelstring = [str(m) for m in MM]
         for k, c in enumerate(['XM1', 'XM2', 'XM3']):
             ax1 = fig.add_subplot(3, 2, 2 * k + 1, sharex=ax)
             ax1.plot(self[label]['sp'], np.real(self[label][c]))
+            for i, line in enumerate(ax1.lines):
+                line.set_label(labelstring[i])
+            lines1 = ax1.get_lines()
+            labelLines(lines1[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax1.set_title('Re($X^%d_m$)' % (k + 1), y=0.8)
             ax2 = fig.add_subplot(3, 2, 2 * (k + 1), sharex=ax)
             ax2.plot(self[label]['sp'], np.imag(self[label][c]))
+            for i, line in enumerate(ax2.lines):
+                line.set_label(labelstring[i])
+            lines2 = ax2.get_lines()
+            labelLines(lines2[np.abs(np.min(MM))+1:np.abs(np.min(MM))+Mmax+1], xvals=(0.,1.), align=False)
             ax2.set_title('Im($X^%d_m$)' % (k + 1), y=0.8)
         ax1.set_xlabel('sp')
         ax2.set_xlabel('sp')
