@@ -12,6 +12,7 @@ except ImportError as _excp:
     else:
         raise
 
+import numpy as np
 from omfit_classes.omfit_path import OMFITpath
 from omfit_classes.omfit_ascii import OMFITascii
 from omfit_classes.sortedDict import OMFITdataset
@@ -20,6 +21,8 @@ from omfit_classes.omfit_gacode import OMFITgacode
 from omfit_classes.omfit_asciitable import OMFITasciitable
 
 __all__ = [
+    'OMFITtglfEPinput',
+    'OMFITalphaInput',
     'OMFITtglf_eig_spectrum',
     'OMFITtglf_wavefunction',
     'OMFITtglf_flux_spectrum',
@@ -33,6 +36,73 @@ __all__ = [
 ]
 
 
+class OMFITtglfEPinput(OMFITascii, SortedDict):
+    '''
+    Class used to read/write TGLFEP input files
+    '''
+
+    def __init__(self, filename, **kw):
+        OMFITascii.__init__(self, filename, **kw)
+        SortedDict(self)
+        self.dynaLoad = True
+
+    @dynaLoad
+    def load(self):
+        with open(self.filename, 'r') as f:
+            lines = f.read()
+
+        widths = []
+        for line in lines.split('\n'):
+            if not len(line.strip()):
+                continue
+            try:
+                if len(widths):
+                    self['WIDTHS'] = widths
+                value, key = line.split()
+            except ValueError:  # not enough values to unpack
+                widths.append(eval(line))
+            else:
+                if value == '.false.':
+                    value = False
+                elif value == '.true.':
+                    value = True
+                else:
+                    value = eval(value)
+                self[key] = value
+
+    @dynaSave
+    def save(self):
+        txt = []
+        for key, value in self.items():
+            if key == 'WIDTHS':
+                continue
+            if value is False:
+                value = '.false.'
+            elif value is True:
+                value = '.true.'
+            txt.append(f'{value} {key}')
+            if key == 'WIDTH_IN_FLAG' and 'WIDTHS' in self:
+                txt.append('\n'.join(map(str, self['WIDTHS'])))
+        with open(self.filename, 'w') as f:
+            f.write('\n'.join(txt))
+
+
+class OMFITalphaInput(OMFITascii, SortedDict):
+    def __init__(self, filename, **kw):
+        OMFITascii.__init__(self, filename, **kw)
+        SortedDict(self)
+        self.dynaLoad = True
+
+    @dynaLoad
+    def load(self):
+        with open(self.filename, 'r') as f:
+            lines = f.read().strip().split('\n')
+        comment = lines[0]
+        data = np.array(list(map(eval, lines[1:])))
+        self['comment'] = comment
+        self['data'] = data
+
+
 def get_ky_spectrum(filename):
     with open(filename, 'r') as f:
         content = f.readlines()
@@ -551,7 +621,6 @@ class OMFITtglf_fluct_spectrum(OMFITdataset, OMFITascii):
 
 
 class OMFITtglf_intensity_spectrum(OMFITdataset, OMFITascii):
-
     '''
     Parse the intensity fluctuation spectrum in
     out.tglf.{density,temperature}_spectrum  and provide a convenient means for
@@ -1025,9 +1094,7 @@ def intensity_sat0(
     intensity_out[
         intensity_out == 0
     ] = 10e10  # when EV solver did not converge, intensity and potential are zero; change zeros to large number before division
-    return (
-        intensity_out
-    )  # Careful: This still needs to be normalized; next operation is intensity_out = intensity_out * potential(TGLF SAT0 output) / intensity_out(default SAT0 params)
+    return intensity_out  # Careful: This still needs to be normalized; next operation is intensity_out = intensity_out * potential(TGLF SAT0 output) / intensity_out(default SAT0 params)
     # See example with default parameters below and regression test 'omfit/regression/test_tglf_satpy.py'
 
 
